/* ================================== */
/* LLREK LICENSE */
/* ================================== */
/* Copyright (c) 2013 Carnegie Mellon University. */
/* All Rights Reserved. */

/* Redistribution and use in source and binary forms, with or without */
/* modification, are permitted provided that the following conditions are */
/* met: */

/* 1. LLREK includes and/or makes use of certain third party software */
/* ("Third Party Software"). You agree to comply with any and all the */
/* Third Party Software terms and conditions listed below and/or */
/* contained in any separate license file distributed with LLREK. The */
/* parties who own the Third Party Software ("Third Party Licensors") are */
/* intended third party beneficiaries to this License with respect to the */
/* terms applicable to their Third Party Software. */

/* 2. Redistributions of source code must retain the above copyright */
/* notice, this list of conditions and the following acknowledgments and */
/* disclaimers. */

/* 3. Redistributions in binary form must reproduce the above copyright */
/* notice, this list of conditions and the following acknowledgments and */
/* disclaimers in the documentation and/or other materials provided with */
/* the distribution. */

/* 4. Products derived from this software may not include Carnegie */
/* Mellon University, "SEI and/or Software Engineering */
/* Institute" in the name of such derived product, nor shall Carnegie */
/* Mellon University, "SEI and/or Software Engineering */
/* Institute" be used to endorse or promote products derived from this */
/* software without prior written permission. For written permission, */
/* please contact permission@sei.cmu.edu. */

/* This material is based upon work funded and supported by the */
/* Department of Defense under Contract No. FA8721-05-C-0003 with */
/* Carnegie Mellon University for the operation of the Software */
/* Engineering Institute, a federally funded research and development */
/* center. */

/* Any opinions, findings and conclusions or recommendations expressed in */
/* this material are those of the author(s) and do not necessarily */
/* reflect the views of the United States Department of Defense. */

/* NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE ENGINEERING */
/* INSTITUTE MATERIAL IS FURNISHEDON AN AS-IS BASIS. CARNEGIE */
/* MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR */
/* IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT LIMITED TO, WARRANTY OF */
/* FITNESS FOR PURPOSE OR MERCHANTABILITY, EXCLUSIVITY, OR RESULTS */
/* OBTAINED FROM USE OF THE MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT */
/* MAKE ANY WARRANTY OF ANY KIND WITH RESPECT TO FREEDOM FROM PATENT, */
/* TRADEMARK, OR COPYRIGHT INFRINGEMENT. */

/* This material has been approved for public release and unlimited */
/* distribution. */

/* DM-0000665 */

#ifndef __BVC_BVCUTIL_HPP__
#define __BVC_BVCUTIL_HPP__

#include "llvm/Support/raw_ostream.h"
#include "llvm/Target/TargetData.h"

#include "ufo/Cpg/Topo.hpp"
#include "ufo/Cpg/Wto.hpp"
#include "ufo/Util/NameValues.hpp"

#include "ufo/Smt/UfoZ3.hpp"
#include "ufo/CptLiveValues.hpp"

using namespace llvm;
using namespace ufo;

namespace ufo
{  

  ///given a bit-vector expression, return its equality with 1. we
  ///assume that the argument has width 1. otherwise, things can
  ///break.
  Expr eqOne(Expr x);

  ///given a bit-vector expression, return its equality with 0. we
  ///assume that the argument has width 1. otherwise, things can
  ///break.
  Expr eqZero(Expr x);

  namespace bitvc
  {
    //the target data, useful to compute bit-widths of types
    extern TargetData *TD;
    
    //-- return the bit-width of a value
    unsigned getBW(const Value *v);
    
    //-- return the bit-width of an expression. must be a a function
    //-- application of a declaration. the declaration contains a
    //-- bvsort which has the bit-width
    unsigned getBW(const Expr &e);

  } //namespace bitvc

} //namespace ufo

#endif //__BVC_BVCUTIL_HPP__
