#!/bin/bash
TMPD=`mktemp -d`

if [ "$#" != "2" ]; then
    echo "Usage : $0 <llrek-log-folder> <rekh-log-folder>"
    echo "Example : $0 brunch.llrek-stp brunch.rekh"
    exit 1
fi

LLREK="$1"
REKH="$2"

echo $LLREK
echo $REKH
echo $TMPD

##convert time ($1) to seconds, if status ($2) is not failed or successful return *
function get_time {
    if [ "$2" == "FAILED" ] || [ "$2" == "SUCCESSFUL" ]; then
        X=$(echo $1 | awk -F':' '{print $1}')
        if [ "x$X" == "x" ]; then X="0"; fi
        Y=$(echo $1 | awk -F':' '{print $2}')
        if [ "x$Y" == "x" ]; then 
            printf "%3.0f\n" $X
        else            
            Z=$(echo "60 * $X + $Y" | bc -l)
            printf "%3.0f\n" $Z
        fi
        #echo $1
    else
        echo "UNK"
    fi
}

function get_vars {
    if [ "x$1" == "x" ] || [ "$1" == "BRUNCH_STAT" ]; then
        echo "UNK"
    else
        X=$(echo "$1 / 1000" | bc -l)
        printf "%4.0f\n" $X
    fi
}

function get_clss {
    if [ "x$1" == "x" ] || [ "$1" == "BRUNCH_STAT" ]; then
        echo "UNK"
    else
        X=$(echo "$1 / 1000" | bc -l)
        printf "%4.0f\n" $X
    fi
}

function create_row {
    X="$1"
    NONE_STAT=$(echo $X | awk -F',' '{print $3}')
    NONE_TIME=$(get_time $(echo $X | awk -F',' '{print $2}') $NONE_STAT)
    NONE_VARS=$(get_vars $(echo $X | awk -F',' '{print $4}'))
    NONE_CLSS=$(get_clss $(echo $X | awk -F',' '{print $5}'))
    
    ALL_STAT=$(echo $X | awk -F',' '{print $7}')
    ALL_TIME=$(get_time $(echo $X | awk -F',' '{print $6}') $ALL_STAT)
    ALL_VARS=$(get_vars $(echo $X | awk -F',' '{print $8}'))
    ALL_CLSS=$(get_clss $(echo $X | awk -F',' '{print $9}'))
    
    WRITE_STAT=$(echo $X | awk -F',' '{print $11}')
    WRITE_TIME=$(get_time $(echo $X | awk -F',' '{print $10}') $WRITE_STAT)
    WRITE_VARS=$(get_vars $(echo $X | awk -F',' '{print $12}'))
    WRITE_CLSS=$(get_clss $(echo $X | awk -F',' '{print $13}'))
    
    X="$2"
    REKH_STAT=$(echo $X | awk -F',' '{print $5}')
    REKH_TIME=$(get_time $(echo $X | awk -F',' '{print $2}') $REKH_STAT)
    REKH_VARS=$(get_vars $(echo $X | awk -F',' '{print $3}'))
    REKH_CLSS=$(get_clss $(echo $X | awk -F',' '{print $4}'))
}

echo "#########################################################################"
echo "############ table 1"
echo "#########################################################################"
for j in 1 4; do
    for i in nxt.bug1 nxt.bug2 nxt.ok1 nxt.ok2 nxt.ok3 aso.bug1 aso.bug2 aso.bug3 aso.bug4 aso.ok1 aso.ok2; do
        X=$(cat $LLREK/stats | grep $i | grep "DM=$j")
        Y=$(cat $REKH/stats | grep $i | grep "DM=$j")
        create_row "$X" "$Y"
        printf "\\hline %12s & %4s & %4s & %4s & %4s & %5s & %5s & %5s & %5s & %5s & %5s & %5s & %5s \\\\\\\\\n" "${i}:H${j}" \
            $NONE_TIME $ALL_TIME $WRITE_TIME $REKH_TIME $NONE_VARS $ALL_VARS $WRITE_VARS $REKH_VARS $NONE_CLSS $ALL_CLSS $WRITE_CLSS $REKH_CLSS \
            | sed 's/UNK/*  /g'
    done
done

for i in ctm.bug2 ctm.bug3 ctm.ok1 ctm.ok2 ctm.ok3 ctm.ok4; do
    X=$(cat $LLREK/stats | grep $i)
    Y=$(cat $REKH/stats | grep $i)
    create_row "$X" "$Y"
    printf "\\hline %12s & %4s & %4s & %4s & %4s & %5s & %5s & %5s & %5s & %5s & %5s & %5s & %5s \\\\\\\\\n" "${i}" \
        $NONE_TIME $ALL_TIME $WRITE_TIME $REKH_TIME $NONE_VARS $ALL_VARS $WRITE_VARS $REKH_VARS $NONE_CLSS $ALL_CLSS $WRITE_CLSS $REKH_CLSS \
        | sed 's/UNK/*  /g'
done

echo "#########################################################################"
echo "############ table 2"
echo "#########################################################################"
./brunch --out $TMPD/brunch.out --format File:NONE-avgObs:ALL-avgObs:WRITE-avgObs:NONE-numObs:ALL-numObs:WRITE-numObs $LLREK/*.stdout -- ./obs-stats
cat $TMPD/brunch.out/stats | grep -v "NONE" | sed 's/-DM=/H/g' | sed 's/.stdout//g' \
    | awk -F',' '{printf "%11s & %5.1f & %1.1f & %1.1f & %4s & %4s & %4s\n",$1,$2,$3,$4,$5,$6,$7}' \
    | awk 'NR%2==1 {prev=$0} NR%2==0 {print "\\hline " prev " & " $0 " \\\\"} END {if (NR%2==1) {print $0 ":"}}'

